@@ -1,23 +1,27 @@
 #!/usr/bin/perl -w
-# $Id: code-style.pl,v 1.9.2.1 2005-08-17 20:03:29 dries Exp $
 
-# Author: Alexander Schwartz (alexander.schwartz@gmx.net)
-# Licence: GPL
-# First version: 2001-10-15
+use Pod::Usage;
+use Getopt::Long qw(GetOptions);
+Getopt::Long::Configure ("bundling");
 
-# Originally written for Drupal (http://www.drupal.org/) to ensure stylish
-# code.  This program tries to show as many improvements as possible with
-# no false positives.
+my %opt = (  "help" => 0,
+    'debug' => 0,
+  );
 
-$comment = 0;
-$program = 0;
-if ($ARGV[0] eq '-debug') {
-  $debug=1;
-  shift (@ARGV);
-}
-else {
-  $debug=0;
+if(!GetOptions(\%opt,
+    'help|?',
+    'debug',
+    )) {
+  pod2usage(-exitval => 1, 'verbose'=>0);
 }
+
+pod2usage(-exitval => 0, -verbose => 2) if($opt{'help'});
+
+$debug = $opt{'debug'};
+
+$comment = 0; #flag used to signal we're inside /* */
+$program = 0; #flag used to signal we're inside <?php ?>
+#read the file
 while (<>) {
   $org=$_;
   s/\\["']//g;
@@ -114,7 +118,7 @@ while (<>) {
   elsif (/([\(\[]) / && $program) {
     $msg = "'$1 ' -> '$1'";
   }
-  elsif (/ ([\)\]])/ && $program) {
+  elsif (/\S ([\)\]])/ && $program) {
     $msg = "' $1' -> '$1'";
   }
   # but no brackets
@@ -132,7 +136,7 @@ while (<>) {
     $msg = "missing space after ','";
   }
   # spaces before and after, only foreach may use $foo=>bar
-  elsif (/[^ =|-|\+](\+|\-)[^ =>|-|\+]/ && $program && !/foreach/) {
+  elsif (/[^ =|\-|\+](\+|\-)[^ =>|\-|\+]/ && $program && !/foreach/) {
     $msg = "'$1' -> ' $1 '";
   }
   elsif (/[^ =](\*|==|\.=|=>|=|\|\|)[^ =>]/ && $program && !/foreach/) {
@@ -158,3 +162,33 @@ while (<>) {
 } continue {
   close ARGV if eof;
 }
+
+__END__
+
+=head1 NAME
+
+code-style.pl - Review drupal code for style
+
+=head1 SYNOPSIS
+
+  code-style.pl [options] <filename>
+
+  Options:
+
+  -? --help  detailed help message
+
+=head1 DESCRIPTION
+
+Originally written for Drupal (http://drupal.org/) to ensure stylish
+code.  This program reviews PHP code, and tries to show as many code
+improvements as possible with no false positives.
+
+=head1 OPTIONS
+
+  --comment
+
+=head1 EXAMPLES
+
+ ./code-style.pl ../index.php
+
+=cut
